def alloy_properties() -> list[dict[str, str]]:
    return [
        {
            "Name": "Ti6Al4V",
            "Density": "4.43",
            "Thermal conductivity": "7.1",
            "Melting temperature (C)": "1695",
            "Coefficient of thermal expansion": "8.6",
            "Specific heat": "561.5",
        },
        {
            "Name": "IN718",
            "Density": "8.19",
            "Thermal conductivity": "9",
            "Melting temperature (C)": "1298",
            "Coefficient of thermal expansion": "14",
            "Specific heat": "435",
        },
        {
            "Name": "SS316L",
            "Density": "7.99",
            "Thermal conductivity": "16.2",
            "Melting temperature (C)": "1385",
            "Coefficient of thermal expansion": "16",
            "Specific heat": "500",
        },
        {
            "Name": "AlSi10Mg",
            "Density": "2.68",
            "Thermal conductivity": "160",
            "Melting temperature (C)": "580",
            "Coefficient of thermal expansion": "20.5",
            "Specific heat": "910",
        },
        {
            "Name": "IN625",
            "Density": "8.44",
            "Thermal conductivity": "9.2",
            "Melting temperature (C)": "1320",
            "Coefficient of thermal expansion": "12.8",
            "Specific heat": "429",
        },
        {
            "Name": "Maraging steel M300",
            "Density": "8.1",
            "Thermal conductivity": "14.2",
            "Melting temperature (C)": "1413",
            "Coefficient of thermal expansion": "10.3",
            "Specific heat": "452",
        },
        {
            "Name": "Ti6Al4V ELI",
            "Density": "4.42",
            "Thermal conductivity": "7",
            "Melting temperature (C)": "1650",
            "Coefficient of thermal expansion": "8.5",
            "Specific heat": "526",
        },
        {
            "Name": "SS17-4PH",
            "Density": "7.8",
            "Thermal conductivity": "16",
            "Melting temperature (C)": "1420",
            "Coefficient of thermal expansion": "10.4",
            "Specific heat": "460",
        },
        {
            "Name": "CoCrMo",
            "Density": "8.4",
            "Thermal conductivity": "13",
            "Melting temperature (C)": "1390",
            "Coefficient of thermal expansion": "14",
            "Specific heat": "450",
        },
        {
            "Name": "H13 Tool Steel",
            "Density": "7.8",
            "Thermal conductivity": "28.6",
            "Melting temperature (C)": "1427",
            "Coefficient of thermal expansion": "10.4",
            "Specific heat": "460",
        },
        {
            "Name": "AlSi7Mg0.6",
            "Density": "2.67",
            "Thermal conductivity": "140",
            "Melting temperature (C)": "570",
            "Coefficient of thermal expansion": "21.5",
            "Specific heat": "890",
        },
        {
            "Name": "SS15-5PH",
            "Density": "7.8",
            "Thermal conductivity": "11",
            "Melting temperature (C)": "1420",
            "Coefficient of thermal expansion": "10.8",
            "Specific heat": "420",
        },
        {
            "Name": "CuCrZr",
            "Density": "8.9",
            "Thermal conductivity": "320",
            "Melting temperature (C)": "1085",
            "Coefficient of thermal expansion": "17",
            "Specific heat": "380",
        },
        {
            "Name": "Al12Si",
            "Density": "2.7",
            "Thermal conductivity": "175",
            "Melting temperature (C)": "680",
            "Coefficient of thermal expansion": "22.3",
            "Specific heat": "922",
        },
        {
            "Name": "Copper",
            "Density": "8.6",
            "Thermal conductivity": "350",
            "Melting temperature (C)": "1085",
            "Coefficient of thermal expansion": "17.01",
            "Specific heat": "435",
        },
        {
            "Name": "Hastelloy X",
            "Density": "8.2",
            "Thermal conductivity": "9.1",
            "Melting temperature (C)": "1355",
            "Coefficient of thermal expansion": "13.9",
            "Specific heat": "486",
        },
        {
            "Name": "CoCr",
            "Density": "8.3",
            "Thermal conductivity": "13",
            "Melting temperature (C)": "1413.75",
            "Coefficient of thermal expansion": "12",
            "Specific heat": "390",
        },
        {
            "Name": "Hastelloy C22",
            "Density": "8.69",
            "Thermal conductivity": "8.9",
            "Melting temperature (C)": "1399",
            "Coefficient of thermal expansion": "12.4",
            "Specific heat": "414",
        },
        {
            "Name": "SS254",
            "Density": "8.07",
            "Thermal conductivity": "14",
            "Melting temperature (C)": "1355",
            "Coefficient of thermal expansion": "14.8",
            "Specific heat": "500",
        },
        {
            "Name": "CuNi2SiCr",
            "Density": "8.84",
            "Thermal conductivity": "90",
            "Melting temperature (C)": "1050",
            "Coefficient of thermal expansion": "17.5",
            "Specific heat": "397",
        },
        {
            "Name": "D2 Tool Steel",
            "Density": "7.7",
            "Thermal conductivity": "20",
            "Melting temperature (C)": "1421",
            "Coefficient of thermal expansion": "10.3",
            "Specific heat": "460",
        },
        {
            "Name": "SS4340",
            "Density": "7.85",
            "Thermal conductivity": "44.5",
            "Melting temperature (C)": "1427",
            "Coefficient of thermal expansion": "12.3",
            "Specific heat": "475",
        },
        {
            "Name": "Invar36",
            "Density": "8.1",
            "Thermal conductivity": "12.8",
            "Melting temperature (C)": "1727",
            "Coefficient of thermal expansion": "1.5",
            "Specific heat": "515",
        },
        {
            "Name": "SS304L",
            "Density": "8",
            "Thermal conductivity": "16.2",
            "Melting temperature (C)": "1693",
            "Coefficient of thermal expansion": "17.3",
            "Specific heat": "500",
        },
        {
            "Name": "Ti grade 2",
            "Density": "4.5",
            "Thermal conductivity": "22",
            "Melting temperature (C)": "1665",
            "Coefficient of thermal expansion": "8.6",
            "Specific heat": "523",
        },
        {
            "Name": "K500",
            "Density": "8.43",
            "Thermal conductivity": "17.5",
            "Melting temperature (C)": "1350",
            "Coefficient of thermal expansion": "13.4",
            "Specific heat": "418",
        },
        {
            "Name": "M2 Tool Steel",
            "Density": "8.055",
            "Thermal conductivity": "41.5",
            "Melting temperature (C)": "1450",
            "Coefficient of thermal expansion": "10",
            "Specific heat": "460",
        },
        {
            "Name": "Ti grade 1",
            "Density": "4.51",
            "Thermal conductivity": "16",
            "Melting temperature (C)": "1668",
            "Coefficient of thermal expansion": "7.17",
            "Specific heat": "520",
        },
        {
            "Name": "CoCr28Mo6",
            "Density": "8.47",
            "Thermal conductivity": "12.5",
            "Melting temperature (C)": "1390",
            "Coefficient of thermal expansion": "13.2",
            "Specific heat": "450",
        },
        {
            "Name": "IN690",
            "Density": "8.19",
            "Thermal conductivity": "13.5",
            "Melting temperature (C)": "1360",
            "Coefficient of thermal expansion": "14.06",
            "Specific heat": "450",
        },
        {
            "Name": "CuCP",
            "Density": "8.9",
            "Thermal conductivity": "320",
            "Melting temperature (C)": "1085",
            "Coefficient of thermal expansion": "17",
            "Specific heat": "385",
        },
        {
            "Name": "TiAlNbMo",
            "Density": "4.112",
            "Thermal conductivity": "22",
            "Melting temperature (C)": "1773",
            "Coefficient of thermal expansion": "12",
            "Specific heat": "600",
        },
        {
            "Name": "SS304",
            "Density": "8",
            "Thermal conductivity": "16.2",
            "Melting temperature (C)": "1693",
            "Coefficient of thermal expansion": "17.3",
            "Specific heat": "500",
        },
        {
            "Name": "TiAl",
            "Density": "4.05",
            "Thermal conductivity": "15",
            "Melting temperature (C)": "1460",
            "Coefficient of thermal expansion": "9",
            "Specific heat": "600",
        },
        {
            "Name": "HY100",
            "Density": "7.75",
            "Thermal conductivity": "34",
            "Melting temperature (C)": "1520",
            "Coefficient of thermal expansion": "14",
            "Specific heat": "460",
        },
        {
            "Name": "AlSi12",
            "Density": "2.685",
            "Thermal conductivity": "140",
            "Melting temperature (C)": "579",
            "Coefficient of thermal expansion": "20",
            "Specific heat": "548.6",
        },
        {
            "Name": "CoCrF75",
            "Density": "8.35",
            "Thermal conductivity": "14",
            "Melting temperature (C)": "1390",
            "Coefficient of thermal expansion": "14",
            "Specific heat": "390",
        },
        {
            "Name": "AZ91D",
            "Density": "1.81",
            "Thermal conductivity": "72",
            "Melting temperature (C)": "533",
            "Coefficient of thermal expansion": "25.2",
            "Specific heat": "1047",
        },
        {
            "Name": "CoCrW",
            "Density": "8.6",
            "Thermal conductivity": "15",
            "Melting temperature (C)": "1370",
            "Coefficient of thermal expansion": "14.1",
            "Specific heat": "390",
        },
        {
            "Name": "SS420C",
            "Density": "7.8",
            "Thermal conductivity": "24.9",
            "Melting temperature (C)": "1480",
            "Coefficient of thermal expansion": "10.3",
            "Specific heat": "460",
        },
        {
            "Name": "SS4130",
            "Density": "7.85",
            "Thermal conductivity": "42.7",
            "Melting temperature (C)": "1432",
            "Coefficient of thermal expansion": "14.6",
            "Specific heat": "523",
        },
        {
            "Name": "CuCrZrTi",
            "Density": "8.9",
            "Thermal conductivity": "320",
            "Melting temperature (C)": "1085",
            "Coefficient of thermal expansion": "17",
            "Specific heat": "380",
        },
        {
            "Name": "8620L Steel",
            "Density": "7.85",
            "Thermal conductivity": "46.6",
            "Melting temperature (C)": "1430",
            "Coefficient of thermal expansion": "6.6",
            "Specific heat": "475",
        },
        {
            "Name": "Al2319",
            "Density": "2.84",
            "Thermal conductivity": "170",
            "Melting temperature (C)": "600",
            "Coefficient of thermal expansion": "22.5",
            "Specific heat": "864",
        },
        {
            "Name": "Iron (0.004%C)",
            "Density": "7.86",
            "Thermal conductivity": "50",
            "Melting temperature (C)": "1535",
            "Coefficient of thermal expansion": "7",
            "Specific heat": "460",
        },
        {
            "Name": "SS316",
            "Density": "7.99",
            "Thermal conductivity": "16.2",
            "Melting temperature (C)": "1385",
            "Coefficient of thermal expansion": "16",
            "Specific heat": "500",
        },
        {
            "Name": "Iron (0.02%C)",
            "Density": "7.86",
            "Thermal conductivity": "50",
            "Melting temperature (C)": "1535",
            "Coefficient of thermal expansion": "7",
            "Specific heat": "460",
        },
        {
            "Name": "Mar M 247",
            "Density": "7.8",
            "Thermal conductivity": "15",
            "Melting temperature (C)": "1220",
            "Coefficient of thermal expansion": "12.8",
            "Specific heat": "230",
        },
        {
            "Name": "W22Fe33Ni",
            "Density": "17.6",
            "Thermal conductivity": "27",
            "Melting temperature (C)": "3410",
            "Coefficient of thermal expansion": "4.5",
            "Specific heat": "134",
        },
        {
            "Name": "4140 Steel",
            "Density": "7.85",
            "Thermal conductivity": "42.6",
            "Melting temperature (C)": "1416",
            "Coefficient of thermal expansion": "12.2",
            "Specific heat": "473",
        },
        {
            "Name": "S50C",
            "Density": "7.85",
            "Thermal conductivity": "21",
            "Melting temperature (C)": "1380",
            "Coefficient of thermal expansion": "13.2",
            "Specific heat": "486",
        },
        {
            "Name": "S75C",
            "Density": "7.85",
            "Thermal conductivity": "25",
            "Melting temperature (C)": "1400",
            "Coefficient of thermal expansion": "13",
            "Specific heat": "480",
        },
        {
            "Name": "A2 Tool Steel",
            "Density": "7.86",
            "Thermal conductivity": "26",
            "Melting temperature (C)": "1420",
            "Coefficient of thermal expansion": "10.6",
            "Specific heat": "461",
        },
        {
            "Name": "S105C",
            "Density": "7.872",
            "Thermal conductivity": "53",
            "Melting temperature (C)": "1430",
            "Coefficient of thermal expansion": "12.6",
            "Specific heat": "481",
        },
        {
            "Name": "SS CX",
            "Density": "7.69",
            "Thermal conductivity": "16.2",
            "Melting temperature (C)": "1450",
            "Coefficient of thermal expansion": "11.1",
            "Specific heat": "502",
        },
        {
            "Name": "7050 alloy",
            "Density": "2.7",
            "Thermal conductivity": "180",
            "Melting temperature (C)": "494",
            "Coefficient of thermal expansion": "23.5",
            "Specific heat": "860",
        },
        {
            "Name": "S33C",
            "Density": "7.85",
            "Thermal conductivity": "34",
            "Melting temperature (C)": "1400",
            "Coefficient of thermal expansion": "13",
            "Specific heat": "475",
        },
        {
            "Name": "IN600",
            "Density": "8.47",
            "Thermal conductivity": "14.8",
            "Melting temperature (C)": "1380",
            "Coefficient of thermal expansion": "13.3",
            "Specific heat": "444",
        },
        {
            "Name": "Nb",
            "Density": "8.4",
            "Thermal conductivity": "53.7",
            "Melting temperature (C)": "2410",
            "Coefficient of thermal expansion": "7.1",
            "Specific heat": "260",
        },
    ]
